@@ -1,8 +1,12 @@
 rIC <- function(obj){
 
+
+if(obj$robust == FALSE) stop("This function allows only for robust model objects.")
+
+
 fit <- obj
 m1d  <- c("PO", "ZTP")
-m2d  <- c("NBI", "NBII","NBIa", "NBIIa","PIG","DGP")
+m2d  <- c("NBI", "NBII","NBIa", "NBIIa","PIG","DGP","DGPII")
 
 n      <- fit$VC$n
 rc     <- fit$VC$rc
@@ -10,14 +14,11 @@ margin <- fit$VC$margins[2]
 weights <- fit$VC$weights
 
 
-
-
 #################################################################
 #################################################################
 #################################################################
 
 
-
 if(margin %in% c(m1d, m2d) ){
 
 
@@ -57,9 +58,10 @@ if( length(sigma2)==1){ sigma2 <- rep(sigma2, n); sigma2.st <- rep(sigma2.st, n)
 if(no.splits > 1){
 
 sumb <- 0
-gradbit1b <- rep(0, dim(fit$VC$X1)[2])
-gradbit2b <- rep(0, dim(fit$VC$X2)[2])
+gradbit1b <- rep(0, dim(fit$VC$X1)[2]) # 
+gradbit2b <- rep(0, dim(fit$VC$X2)[2]) # 
 
+iter.split <- 1
 
 for(i in 1:no.splits){
 
@@ -78,27 +80,33 @@ if( margin %in% m2d ) X2L <- apply(as.matrix(fit$VC$X2[num.ind==i,]), 2, rep, ea
 
  if( margin %in% m1d ){
  
-g1b <- c( weightsL*gradBbit1(ygridL, etaL, sigma2L, sigma2.stL, 1, 1, margin, rc, discr = TRUE, ym) )*X1L 
+   g1b <- c( weightsL*gradBbit1(ygridL, etaL, sigma2L, sigma2.stL, 1, 1, margin, rc, discr = TRUE, ym) )*X1L 
+   G1B <- t(g1b)%*%g1b
 
-gradbit1b <- gradbit1b - t(g1b)%*%g1b # sign minus should be ok
+     if(iter.split == 1) gradbit1b <- matrix(0, dim(G1B), dim(G1B))
 
-}
+   gradbit1b <- gradbit1b - G1B # sign minus should be ok
+
+
+                     }
 
 
   if( margin %in% m2d ){
   
      
      g1b <- c( weightsL*gradBbit1(ygridL, etaL, sigma2L, sigma2.stL, 1, 1, margin, rc, discr = TRUE, ym) )*X1L 
-  
      g2b <- c( weightsL*gradBbit2(ygridL, etaL, sigma2L, sigma2.stL, 1, 1, margin, rc, discr = TRUE, ym) )*X2L
+     gb  <- cbind(g1b, g2b)
+     GB  <- t(gb)%*%gb
      
-     gb <- cbind(g1b, g2b)
-     
-     
-     gradbit2b <- gradbit2b - t(gb)%*%gb
+       if(iter.split == 1) gradbit2b <- matrix(0, dim(GB), dim(GB))
+
+     gradbit2b <- gradbit2b - GB
                 
                        }
-                     
+  
+  iter.split <- iter.split + 1
+  
   } 
                      
                      
@@ -184,7 +192,7 @@ if(margin %in% m2d) g <- cbind(  c(fit$fit$dl.dbe)*fit$VC$X1, c(fit$fit$dl.dsigm
 if(!(margin %in% c(m1d, m2d)) ){
 
 
-m2sel <- c("WEI","iG","GA","BE","FISK","DAGUM","SM","GP")
+m2sel <- c("WEI","iG","GA","BE","FISK","DAGUM","SM","TW","GP","GPII","GPo")
 
 ###############################
 # fixed quantities
@@ -198,8 +206,8 @@ if(is.null(fit$VC$X2)){fit$VC$X2 <- fit$VC$X3 <- matrix(1, n, 1); fit$VC$X2.d2 <
 if(is.null(fit$VC$lB) && is.null(fit$VC$uB)){
 
 if( margin %in% c("N","N2","GU","rGU","LO","LN") )             { lB <- -Inf;      uB <- Inf}
-if( margin %in% c("WEI","iG","GA","DAGUM","SM","FISK","GP")  )      { lB <- 0.0000001; uB <- Inf}
-if( margin %in% c("BE")  )                                     { lB <- 0.0000001; uB <- 0.9999999}
+if( margin %in% c("WEI","iG","GA","DAGUM","SM","FISK","GP","GPII","GPo","TW")  ) { lB <- sqrt(.Machine$double.eps); uB <- Inf} # tw not test, 0 included?
+if( margin %in% c("BE")  )                                     { lB <- sqrt(.Machine$double.eps); uB <- 0.9999999}
 
 }else{lB <- fit$VC$lB; uB <- fit$VC$uB}
 
@@ -213,7 +221,7 @@ ss  <- esp.tr(fit$VC$X2%*%fit$coefficients[(1+fit$VC$X1.d2):(fit$VC$X1.d2+fit$VC
 sigma2    <- ss$vrb
 sigma2.st <- ss$vrb.st
 
-if( margin %in% c("DAGUM","SM") ){
+if( margin %in% c("DAGUM","SM","TW") ){
 
             nus   <- enu.tr(fit$VC$X3%*%fit$coefficients[(1+fit$VC$X1.d2+fit$VC$X2.d2):(fit$VC$X1.d2+fit$VC$X2.d2+fit$VC$X3.d2)], margin)
             nu    <- nus$vrb
@@ -242,7 +250,7 @@ intgrad   <- v.intgrad(eta = eta, sigma2 = sigma2, sigma2.st = sigma2.st, nu = n
 gradbit2  <- -c(weights*intgrad)*fit$VC$X2 
 
 
-if( margin %in% c("DAGUM","SM") ){
+if( margin %in% c("DAGUM","SM","TW") ){
 
 intgrad   <- function(eta, sigma2, sigma2.st, nu, nu.st, margin, rc, lB, uB) distrExIntegrate(gradBbit3, lower = lB, upper = uB, eta = eta, sigma2 = sigma2, sigma2.st = sigma2.st, nu = nu, nu.st = nu.st, margin = margin, rc = rc)              
 v.intgrad <- Vectorize(intgrad) 
@@ -312,17 +320,15 @@ if(!(margin %in% fit$VC$m3)) g <- cbind(  c(fit$fit$dl.dbe)*fit$VC$X1, c(fit$fit
 ###################################################################################################
 
 
-
-
 h <- t(g)%*%g
 
+hbs <- PDef(h - bs)$res
 
+F <- fit$Vb1%*%hbs
 
-hbs <- h - bs
-
-edf <- sum(diag(fit$Vb%*%hbs))
+edf <- sum(diag(F))
                                                                 
-list(bs = bs, h = h, hbs = hbs, rAIC = 2*edf - 2*-fit$fit$l, rBIC = log(n)*edf - 2*-fit$fit$l, edf = edf)
+list(bs = bs, h = h, hbs = hbs, rAIC = 2*edf - 2*-fit$fit$l, rBIC = log(n)*edf - 2*-fit$fit$l, edf = edf, F = F)
 
 
 
