@@ -13,9 +13,11 @@ rlo <- (max(x$VC$y1) - min(x$VC$y1))/lo
 if(rlo > 1) lo <- round(lo*rlo) 
 
 
-if( margin %in% c("N","N2","GU","rGU","LO","LN") )                seq.y <- seq(min(x$VC$y1) - ((max(x$VC$y1) - min(x$VC$y1))/2), max(x$VC$y1) + ((max(x$VC$y1) - min(x$VC$y1))/2), length.out = lo)
-if( margin %in% c("WEI","iG","GA","DAGUM","SM","FISK","GP")  )   seq.y <- seq(1e-12, max(x$VC$y1) + ((max(x$VC$y1) - min(x$VC$y1))/2), length.out = lo)
-if( margin %in% c("BE")  )                                        seq.y <- seq(1e-12, 0.9999999,  length.out = lo)      
+if( margin %in% c("N","N2","GU","rGU","LO","LN") )                            seq.y <- seq(min(x$VC$y1) - ((max(x$VC$y1) - min(x$VC$y1))/2), max(x$VC$y1) + ((max(x$VC$y1) - min(x$VC$y1))/2), length.out = lo)
+if( margin %in% c("WEI","iG","GA","DAGUM","SM","FISK","GP","GPII","GPo")  )   seq.y <- seq(1e-12, max(x$VC$y1) + ((max(x$VC$y1) - min(x$VC$y1))/2), length.out = lo)
+if( margin %in% c("TW")  )   seq.y <- seq(0, max(x$VC$y1) + ((max(x$VC$y1) - min(x$VC$y1))/2), length.out = lo)
+
+if( margin %in% c("BE")  )                                                    seq.y <- seq(1e-12, 0.9999999,  length.out = lo)      
 
 }else{
 
@@ -42,7 +44,7 @@ ss  <- esp.tr(x$VC$X2%*%params[(1+x$VC$X1.d2):(x$VC$X1.d2+x$VC$X2.d2)], margin)
 sigma2    <- ss$vrb
 sigma2.st <- ss$vrb.st
 
-if( margin %in% c("DAGUM","SM") ){
+if( margin %in% c("DAGUM","SM","TW") ){
 
             nus   <- enu.tr(x$VC$X3%*%params[(1+x$VC$X1.d2+x$VC$X2.d2):(x$VC$X1.d2+x$VC$X2.d2+x$VC$X3.d2)], margin)
             nu    <- nus$vrb
@@ -72,7 +74,7 @@ if((is.null(posi) || length(posi) < 2) && margin %in% c("N","N2","GU","rGU","LO"
 
 
 
-if((is.null(posi) || length(posi) < 2) && margin %in% c("WEI","iG","GA","DAGUM","SM","FISK","GP") ){
+if((is.null(posi) || length(posi) < 2) && margin %in% c("WEI","iG","GA","DAGUM","TW","SM","FISK","GP","GPII","GPo") ){
 
 
 posi <- NULL; j <- 1
