@@ -6,7 +6,7 @@ summary.gjrm <- function(object, n.sim = 100, prob.lev = 0.05, ...){
   cont2par  <- c(object$VC$m2,object$VC$m2d) 
   cont3par  <- c(object$VC$m3,object$VC$m3d) 
   n <- object$n  
-  epsilon <- 0.0000001; max.p   <- 0.9999999
+  epsilon <- sqrt(.Machine$double.eps); max.p   <- 0.9999999
 
   lf <- length(object$coefficients)
   Vb <- object$Vb 
@@ -50,15 +50,17 @@ rm(bs, SE, Vb, XX, Xt, V)
               n=n, theta=object$theta, theta.a=object$theta.a,
               dof=object$dof, dof.a=object$dof.a,
               sigma21=object$sigma21, sigma22=object$sigma22, 
+              sigma1=object$sigma21, sigma2=object$sigma22, 
               nu1=object$nu1, nu2=object$nu2, tau=object$tau, 
               sigma21.a=object$sigma21.a, sigma22.a=object$sigma22.a, 
+              sigma1.a=object$sigma21.a, sigma2.a=object$sigma22.a, 
               nu1.a=object$nu1.a, nu2.a=object$nu2.a, 
               tau.a=object$tau.a, formula = object$formula,
               formula1=object$gam1$formula, formula2=object$gam2$formula, formula3=object$gam3$formula,
               formula4=object$gam4$formula, formula5=object$gam5$formula, formula6=object$gam6$formula, 
               formula7=object$gam7$formula, formula8=object$gam8$formula,
               t.edf=object$t.edf, 
-              CItheta=CIrs, CIsig21=CIsig21, CIsig22=CIsig22, CInu1=CInu1, CInu2=CInu2, CItau = CIkt,
+              CItheta=CIrs, CIsig1=CIsig21, CIsig2=CIsig22, CInu1=CInu1, CInu2=CInu2, CItau = CIkt,
               CIdof = CIdof, BivD=object$BivD, margins = object$margins, 
               l.sp1 = object$l.sp1, l.sp2 = object$l.sp2, l.sp3 = object$l.sp3, 
               l.sp4 = object$l.sp4, l.sp5 = object$l.sp5, l.sp6 = object$l.sp6, 
